from setuptools import setup

setup(name='test_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['test_probability'],
      author = 'Ernitia Paramasari',
      zip_safe=False)
